@@ -262,10 +262,10 @@ class MObject(object):
         :param bool is_new: is the object new (i.e. not loaded from the database)
         """
 
-        self.__data = {}
-        self.__delta = {}
-        self.__is_new = is_new
-        self.__relations = {}
+        self._m__data = {}
+        self._m__delta = {}
+        self._m__is_new = is_new
+        self._m__relations = {}
 
         if data:
             for k, v in data.iteritems():
@@ -281,19 +281,23 @@ class MObject(object):
             k = key2
 
         # TODO: catch KeyError
-        del self.__data[k]
+        del self._m__data[k]
 
-        if '$unset' not in self.__delta:
-            self.__delta['$unset'] = {}
-        self.__delta['$unset'][k] = True
+        if '$unset' not in self._m__delta:
+            self._m__delta['$unset'] = {}
+        self._m__delta['$unset'][k] = True
 
-        if '$set' in self.__delta:
-            if k in self.__delta['$set']:
-                del self.__delta['$set'][k]
-                if not self.__delta['$set']:
-                    del self.__delta['$set']
+        if '$set' in self._m__delta:
+            if k in self._m__delta['$set']:
+                del self._m__delta['$set'][k]
+                if not self._m__delta['$set']:
+                    del self._m__delta['$set']
 
     def __setattr__(self, k, v):
+        if k.startswith('_m__'):
+            self.__dict__[k] = v
+            return True
+
         if k == 'id':
             k = '_id'
 
@@ -308,41 +312,44 @@ class MObject(object):
             v = list(v)
         if isinstance(v, MDict):
             v = dict(v)
-        self.__data[k] = v
+        self._m__data[k] = v
 
-        if not self.__is_new:
-            if '$set' not in self.__delta:
-                self.__delta['$set'] = {}
-            self.__delta['$set'][k] = v
+        if not self._m__is_new:
+            if '$set' not in self._m__delta:
+                self._m__delta['$set'] = {}
+            self._m__delta['$set'][k] = v
 
-            if '$unset' in self.__delta:
-                if k in self.__delta['$unset']:
-                    del self.__deleta['$unset'][k]
-                    if not self.__delta['$unset']:
-                        del self.__delta['$unset']
+            if '$unset' in self._m__delta:
+                if k in self._m__delta['$unset']:
+                    del self._m__deleta['$unset'][k]
+                    if not self._m__delta['$unset']:
+                        del self._m__delta['$unset']
 
     def __getattr__(self, k, raw=False, default=None):
+        if k.startswith('_m__'):
+            return self.__dict__[k]
+
         if k == 'id':
             k = '_id'
 
         raw_k = None
         if not raw:
             raw_k = k
-            if k in self.BELONGS_TO and (k not in self.__relations or not isinstance(self.__relations[k], MObject)):
-                self.__relations[k] = BelongsTo.load(self, k, self.BELONGS_TO[k])
-            elif k in self.HAS_MANY and (k not in self.__relations or not isinstance(self.__relations[k], MCursor)):
-                self.__relations[k] = HasMany.load(self, k, self.HAS_MANY[k])
-            elif k in self.BELONGS_TO_MANY and (k not in self.__relations or not isinstance(self.__relations[k], MCursor)):
-                self.__relations[k] = BelongsToMany.load(self, k, self.BELONGS_TO_MANY[k])
+            if k in self.BELONGS_TO and (k not in self._m__relations or not isinstance(self._m__relations[k], MObject)):
+                self._m__relations[k] = BelongsTo.load(self, k, self.BELONGS_TO[k])
+            elif k in self.HAS_MANY and (k not in self._m__relations or not isinstance(self._m__relations[k], MCursor)):
+                self._m__relations[k] = HasMany.load(self, k, self.HAS_MANY[k])
+            elif k in self.BELONGS_TO_MANY and (k not in self._m__relations or not isinstance(self._m__relations[k], MCursor)):
+                self._m__relations[k] = BelongsToMany.load(self, k, self.BELONGS_TO_MANY[k])
 
         if k in self.DEFAULT_VALUES and default is None:
             default = self.DEFAULT_VALUES[k]
 
-        if not raw and k in self.__relations:
-            val = self.__relations[k]
+        if not raw and k in self._m__relations:
+            val = self._m__relations[k]
         else:
             # TODO: catch KeyError and throw appropriate exception
-            val = self.__data.get(k, default) if default is not None else self.__data[k]
+            val = self._m__data.get(k, default) if default is not None else self._m__data[k]
 
         if isinstance(val, list):
             val = MList(val, self, k)
@@ -356,7 +363,7 @@ class MObject(object):
         
         :rtype: dict
         '''
-        return self.__data
+        return self._m__data
 
     def delta(self):
         ''' When making changes to an object, a delta is kept so that when
@@ -368,7 +375,7 @@ class MObject(object):
         
         .. _update doc: http://docs.mongodb.org/manual/core/update/
         '''
-        return self.__delta
+        return self._m__delta
 
     def update(self, **kwargs):
         ''' Update the object in MongoDB.
@@ -392,13 +399,13 @@ class MObject(object):
 
         '''
 
-        if self.__is_new:
+        if self._m__is_new:
             return self.save(**kwargs)
 
         query = {'_id': self.id}
-        if not self.__delta:
+        if not self._m__delta:
             return True
-        doc = self.__delta
+        doc = self._m__delta
 
         if '$set' not in doc:
             doc['$set'] = {}
@@ -409,7 +416,7 @@ class MObject(object):
         response = collection.update(query, doc, **kwargs)
 
         # TODO: Check if a safe write and only clear delta if success
-        self.__delta = {}
+        self._m__delta = {}
         return response
 
     def save(self, **kwargs):
@@ -430,10 +437,10 @@ class MObject(object):
         .. _save(): http://api.mongodb.org/python/current/api/pymongo/collection.html#pymongo.collection.Collection.save
         '''
 
-        if not self.__is_new:
+        if not self._m__is_new:
             return self.update(**kwargs)
 
-        if '_id' not in self.__data:
+        if '_id' not in self._m__data:
             if not self.MONGO_ID:
                 raise Exception('Model {0} does not use ObjectId for _id so _id should be explicitly set.')
             self.id = bson.ObjectId()
@@ -443,10 +450,10 @@ class MObject(object):
         self.date_modified = now
 
         collection = self._get_collection()
-        logging.info(collection.full_name, 'save', self.__data)
-        success = collection.save(self.__data)
+        logging.info(collection.full_name, 'save', self._m__data)
+        success = collection.save(self._m__data)
         if success:
-            self.__is_new = False
+            self._m__is_new = False
         return success
 
     @classmethod
@@ -551,7 +558,7 @@ class MObject(object):
                     response = cls(data=response, is_new=False)
                 return response
         else:
-            loggin.info(collection.full_name, 'find', query)
+            logging.info(collection.full_name, 'find', query)
             response = collection.find(query, **kwargs)
             if response:
                 if 'raw' in kwargs:
